@@ -7,7 +7,7 @@ from . import utils
 from pathlib import Path
 
 # declare the logging object
-logger = logging.getLogger("awsUtils")
+logger = logging.getLogger()
 
 # get working directory to reference relative files
 path = Path(__file__).parent
